pub fn spawn_with_killswitch(fut: impl Future<Output = ()> + Send + 'static)Expand description
Spawns a new asynchronous task and registers it in the crate’s global killswitch.
Under the hood, tokio::spawn schedules the actual execution.
pub fn spawn_with_killswitch(fut: impl Future<Output = ()> + Send + 'static)Spawns a new asynchronous task and registers it in the crate’s global killswitch.
Under the hood, tokio::spawn schedules the actual execution.